Documentation see https://dpowers.readthedocs.io.

This package has not been tested properly, but is running well on my PC 
(Linux Mint). There are probably a lot of bugs still.

I am working on this as a hobby project, and I am happy if it helps others 
too. I do not have that much time right now, but I will work on it occasionally.

Things planned to be improved:
- Extend the documentation. (Reference for all commands)
- Add support for multiple systems/platforms.
- More testing and debugging.
- Explanations on how to add your own powers or backends.